@@ -1,6 +1,6 @@
 import re
 _escape_regex = re.compile(r"[&><\n\r\t]")
-_escape_quote_regex = re.compile(r"[&><\n\r\t;]")
+_escape_quote_regex = re.compile(r"[&><\n\r\t\"]")
 _replacements = {
     '&': '&amp;',
     '<': '&lt;',
